boost library
Classes
- CancellationToken
- ConfigParser
- App configuration parsed from environment variables and command line arguments.
-
GuardResult<
T> - Describes the execution result of a function inside the runGuarded function.
-
Lazy<
T> - A Lazy can be used to only initialize a value if it is required.
- Notifier
- Semaphore
- A semaphore prevents asynchronous code from being executed simultaneously.
-
TypeCheck<
T> - A utility class for checking type parameters.
- Version
- Represents a Version consisting of numeric parts, starting with the most significant part.
Enums
Extensions
- Apply on T
-
CancelableFuture
on Future<
T> -
DoubleIterableMathExtension
on Iterable<
double> -
IntIterableMathExtension
on Iterable<
int> -
IntListExtension
on List<
int> -
IntListStreamExtension
on Stream<
List< int> > -
IterableExtension
on Iterable<
E> -
IterableMathExtension
on Iterable<
TValue> -
ListExtension
on List<
E> -
MapExtension
on Map<
K, V> -
TripleIterableExtension
on Iterable<
(Ta, Tb, Tc)> - Extensions for Iterables of type Triple.
-
TupleIterableExtension
on Iterable<
(Ta, Tb)> - Extensions for Iterables of type Tuple.
- Uint8ListExtension on Uint8List
Functions
-
clamp<
T extends num> (T value, T min, T max) → T - Clamps a value between a inclusive minimum and inclusive maximum.
-
findEnum<
TEnum extends Enum> (String value, Iterable< TEnum> values, {bool ignoreCase = false}) → TEnum - Finds and returns the enum value which matches with the given string value.
-
nullOrEmpty(
String? source) → bool - Returns true if string is either null or empty.
-
nullOrWhitespace(
String? source) → bool - Returns true if string is either null or entirely whitespace.
-
round<
T extends num> (T value, [int digits = 0]) → double - Rounds to given digit count.
-
runGuarded(
Iterable< Future Function(CancellationToken?)> actions, {ExecutionMode executionMode = ExecutionMode.Concurrent, CancellationToken? cancel}) → Future<List< GuardResult> > - Executes multiple async functions concurrent while catching every result or error that is thrown.
-
toDegrees(
num radians) → double - Converts radians to degrees.
-
toRadians(
num degrees) → double - Converts degrees to radians.
-
tryFindEnum<
TEnum extends Enum> (String value, Iterable< TEnum> values, {bool ignoreCase = false}) → TEnum? - Finds and returns the enum value which matches with the given string value.
Exceptions / Errors
- BoostException
- Base class for boost exceptions.
- CanceledException