ListExtension<E> extension

on

Methods

replaceItem(E needle, E replacement, [int start = 0]) → void

Available on List<E>, provided by the ListExtension extension

Replaces a single element of this List with replacement.
sortBy<K extends Comparable>(K selector(E), [bool ascending = true]) → void

Available on List<E>, provided by the ListExtension extension

Sorts this List by comparing the keys returned by the selector.